summaryrefslogtreecommitdiffstats
path: root/style/polish.cpp
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2016-03-25 20:06:45 +0100
committerSlávek Banko <slavek.banko@axis.cz>2016-03-25 20:06:45 +0100
commit88b7febc2393324ee14940c1c41a8ddc342c35f6 (patch)
treeb9a917fd3a40988e6e0134490f5357e5335c1c70 /style/polish.cpp
parent2ee99ab520931c5efe91123c85ba10064a45e95d (diff)
downloadtde-style-baghira-88b7febc2393324ee14940c1c41a8ddc342c35f6.tar.gz
tde-style-baghira-88b7febc2393324ee14940c1c41a8ddc342c35f6.zip
Initial TDE conversion
Signed-off-by: Slávek Banko <slavek.banko@axis.cz>
Diffstat (limited to 'style/polish.cpp')
-rw-r--r--style/polish.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/style/polish.cpp b/style/polish.cpp
index 2f4bbeb..650afc9 100644
--- a/style/polish.cpp
+++ b/style/polish.cpp
@@ -17,8 +17,8 @@
#include <tqlabel.h>
#include <tqlayout.h>
#include <tqlistbox.h>
-#include <klistview.h>
-#include <kmenubar.h>
+#include <tdelistview.h>
+#include <tdemenubar.h>
#include <tqpalette.h>
#include <tqpainter.h>
#include <tqpopupmenu.h>
@@ -30,10 +30,10 @@
#include <tqtabbar.h>
#include <tqtoolbar.h>
#include <tqtoolbutton.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
#include <kpixmapeffect.h>
-#include <kglobalsettings.h>
-#include <kwin.h>
+#include <tdeglobalsettings.h>
+#include <twin.h>
#include <X11/Xlib.h>
#include <X11/Xatom.h>
@@ -376,7 +376,7 @@ void LiquidStyle::polish( TQWidget *w )
- if (qstrcmp( w->name(), "kde toolbar widget" ) == 0 )
+ if (qstrcmp( w->name(), "tde toolbar widget" ) == 0 )
w->installEventFilter( this );
if (::tqt_cast<TQButton*>(w))
@@ -416,7 +416,7 @@ void LiquidStyle::polish( TQWidget *w )
if ( ::tqt_cast<TQToolBar*>(w))
{
- if (optionHandler->useToolButtonFrame() && w->inherits("KToolBar"))
+ if (optionHandler->useToolButtonFrame() && w->inherits("TDEToolBar"))
((TQToolBar*)w)->boxLayout()->setSpacing( 0 );
((TQToolBar*)w)->setMargin( 4 );
w->setBackgroundMode(PaletteBackground);
@@ -434,7 +434,7 @@ void LiquidStyle::polish( TQWidget *w )
}
//if (testWidget) tqWarning("testwidget stage %d",testInt++);
- if (tmpBool = ::tqt_cast<TQToolButton*>(w) || w->inherits( "TQToolBarSeparator" ) || w->inherits( "KToolBarSeparator" ) )
+ if (tmpBool = ::tqt_cast<TQToolButton*>(w) || w->inherits( "TQToolBarSeparator" ) || w->inherits( "TDEToolBarSeparator" ) )
{
if (tmpBool && w->parentWidget() && ::tqt_cast<TQToolBar*>(w->parentWidget()) )
{
@@ -465,10 +465,10 @@ void LiquidStyle::polish( TQWidget *w )
goto kstpolish;
}
- if ( !isPlain () && (w->inherits( "KonqIconViewWidget" ) || w->inherits( "khtml")/* || w->inherits( "TQtVisionView")*/))
+ if ( !isPlain () && (w->inherits( "KonqIconViewWidget" ) || w->inherits( "tdehtml")/* || w->inherits( "TQtVisionView")*/))
{
// if you want custom backgrounds in konqueror, you have to reset pixmap, since Konq animation can't handle it
// original liquid did this on khtml, too (at speed loss) so we'll see, if we get errors from this...
TQPalette pal( w->palette() );
pal.setBrush( TQColorGroup::Background, pal.active().background() );
w->setPalette( pal );
@@ -483,9 +483,9 @@ void LiquidStyle::polish( TQWidget *w )
if ((::tqt_cast<TQScrollView*>(w) || w->inherits("KateView") || w->inherits("TEWidget") || w->inherits("CHexViewWidget")) && !(w->isA("KOAgenda")))
{
- if (::tqt_cast<KListView*>(w) && optionHandler->custCols[7] != -1 && ((KListView*)w)->alternateBackground() == KGlobalSettings::alternateBackgroundColor())
+ if (::tqt_cast<TDEListView*>(w) && optionHandler->custCols[7] != -1 && ((TDEListView*)w)->alternateBackground() == TDEGlobalSettings::alternateBackgroundColor())
{
- ((KListView*)w)->setAlternateBackground(TQColor(optionHandler->custCols[7]));
+ ((TDEListView*)w)->setAlternateBackground(TQColor(optionHandler->custCols[7]));
}
#if _FORCE_SCROLLBARS_
if (::tqt_cast<TQScrollView*>(w) && !w->inherits( "KActiveLabel" ))
@@ -613,7 +613,7 @@ void LiquidStyle::polish( TQWidget *w )
bool italic = w->font().italic();
bool underline = w->font().underline();
bool overline = w->font().overline();
- w->setFont(KGlobalSettings::menuFont());
+ w->setFont(TDEGlobalSettings::menuFont());
if (bold)
(const_cast<TQFont*>(&w->font()))->setBold(true);
if (italic)
@@ -671,7 +671,7 @@ void LiquidStyle::polish( TQWidget *w )
//if (testWidget) tqWarning("testwidget stage %d",testInt++);
- if ( w->parentWidget() && ( ( ::tqt_cast<TQListBox*>(w) && ::tqt_cast<TQPushButton*>(w->parentWidget())) || w->inherits( "KCompletionBox" ) ) ) {
+ if ( w->parentWidget() && ( ( ::tqt_cast<TQListBox*>(w) && ::tqt_cast<TQPushButton*>(w->parentWidget())) || w->inherits( "TDECompletionBox" ) ) ) {
TQListBox* listbox = (TQListBox*) w;
listbox->setBackgroundMode( NoBackground );
w->installEventFilter( this );
@@ -745,7 +745,7 @@ void LiquidStyle::polish( TQWidget *w )
w->setBackgroundMode( TQWidget::NoBackground );
}
//if (testWidget) tqWarning("testwidget stage %d",testInt++);
- kstpolish: KStyle::polish( w ); // nothing of all above? do default kde stuff
+ kstpolish: TDEStyle::polish( w ); // nothing of all above? do default kde stuff
}
@@ -763,7 +763,7 @@ void LiquidStyle::unPolish( TQWidget *w ) {
goto kstunpolish;
}
- if ( w->inherits("TQToolBar") || qstrcmp( w->name(), "kde toolbar widget" ) == 0 ) {
+ if ( w->inherits("TQToolBar") || qstrcmp( w->name(), "tde toolbar widget" ) == 0 ) {
w->setBackgroundOrigin( TQWidget::WidgetOrigin );
// w->unsetPalette();
goto kstunpolish;
@@ -780,7 +780,7 @@ void LiquidStyle::unPolish( TQWidget *w ) {
goto kstunpolish;
}
if ( !isPlain () && w->inherits( "KonqIconViewWidget" ) ||
- w->inherits( "KHTMLView" ) ) {
+ w->inherits( "TDEHTMLView" ) ) {
w->unsetPalette();
goto kstunpolish;
}
@@ -874,5 +874,5 @@ void LiquidStyle::unPolish( TQWidget *w ) {
goto kstunpolish;
}
}
-kstunpolish: KStyle::unPolish( w );
+kstunpolish: TDEStyle::unPolish( w );
}
@@ -465,10 +465,10 @@ void LiquidStyle::polish( TQWidget *w )
{
// if you want custom backgrounds in konqueror, you have to reset pixmap, since Konq animation can't handle it
- // original liquid did this on khtml, too (at speed loss) so we'll see, if we get errors from this...
+ // original liquid did this on tdehtml, too (at speed loss) so we'll see, if we get errors from this...
TQPalette pal( w->palette() );
pal.setBrush( TQColorGroup::Background, pal.active().background() );